@@ -1,9 +1,9 @@
+use czkawka_core::common::regex_check;
+use czkawka_core::common_items::new_excluded_item;
 use gtk4::prelude::*;
 use gtk4::{ResponseType, TreeIter, Window};
 use regex::Regex;
 
-use czkawka_core::common::Common;
-
 use crate::flg;
 use crate::gui_structs::gui_data::GuiData;
 use crate::help_functions::*;
@@ -133,11 +133,11 @@ fn popover_all_except_oldest_newest(
                     break;
                 }
             }
-            if used_index.is_none() {
+            let Some(used_index) = used_index else {
                 continue;
-            }
+            };
             for (index, tree_iter) in tree_iter_array.iter().enumerate() {
-                if index != used_index.unwrap() {
+                if index != used_index {
                     model.set_value(tree_iter, column_button_selection, &true.to_value());
                 } else {
                     model.set_value(tree_iter, column_button_selection, &false.to_value());
@@ -205,11 +205,12 @@ fn popover_one_oldest_newest(
                     break;
                 }
             }
-            if used_index.is_none() {
+            let Some(used_index) = used_index else {
                 continue;
-            }
+            };
+
             for (index, tree_iter) in tree_iter_array.iter().enumerate() {
-                if index == used_index.unwrap() {
+                if index == used_index {
                     model.set_value(tree_iter, column_button_selection, &true.to_value());
                 } else {
                     model.set_value(tree_iter, column_button_selection, &false.to_value());
@@ -369,6 +370,11 @@ fn popover_custom_select_unselect(
             #[cfg(target_family = "windows")]
             let path_wildcard = path_wildcard.replace("/", "\\");
 
+            let name_wildcard_excluded = new_excluded_item(&name_wildcard);
+            let name_wildcard_lowercase_excluded = new_excluded_item(&name_wildcard.to_lowercase());
+            let path_wildcard_excluded = new_excluded_item(&path_wildcard);
+            let path_wildcard_lowercase_excluded = new_excluded_item(&path_wildcard.to_lowercase());
+
             if response_type == ResponseType::Ok {
                 let check_path = check_button_path.is_active();
                 let check_name = check_button_name.is_active();
@@ -387,7 +393,7 @@ fn popover_custom_select_unselect(
                             return;
                         }
                     } else {
-                        Regex::new("").unwrap()
+                        Regex::new("").expect("Empty regex should compile properly.")
                     };
 
                     let model = get_list_store(&tree_view);
@@ -441,22 +447,22 @@ fn popover_custom_select_unselect(
                         } else {
                             if check_name {
                                 if case_sensitive {
-                                    if Common::regex_check(&name_wildcard, &name) {
+                                    if regex_check(&name_wildcard_excluded, &name) {
                                         need_to_change_thing = true;
                                     }
                                 } else {
-                                    if Common::regex_check(&name_wildcard.to_lowercase(), name.to_lowercase()) {
+                                    if regex_check(&name_wildcard_lowercase_excluded, &name.to_lowercase()) {
                                         need_to_change_thing = true;
                                     }
                                 }
                             }
                             if check_path {
                                 if case_sensitive {
-                                    if Common::regex_check(&path_wildcard, &path) {
+                                    if regex_check(&path_wildcard_excluded, &path) {
                                         need_to_change_thing = true;
                                     }
                                 } else {
-                                    if Common::regex_check(&path_wildcard.to_lowercase(), path.to_lowercase()) {
+                                    if regex_check(&path_wildcard_lowercase_excluded, &path.to_lowercase()) {
                                         need_to_change_thing = true;
                                     }
                                 }
@@ -571,11 +577,11 @@ fn popover_all_except_biggest_smallest(
                     break;
                 }
             }
-            if used_index.is_none() {
+            let Some(used_index) = used_index else {
                 continue;
-            }
+            };
             for (index, tree_iter) in tree_iter_array.iter().enumerate() {
-                if index != used_index.unwrap() {
+                if index != used_index {
                     model.set_value(tree_iter, column_button_selection, &true.to_value());
                 } else {
                     model.set_value(tree_iter, column_button_selection, &false.to_value());
@@ -598,7 +604,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
 
     buttons_popover_select_all.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -610,7 +616,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_unselect_all.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -622,7 +628,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_reverse.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -634,7 +640,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_all_except_oldest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -654,7 +660,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_all_except_newest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -674,7 +680,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_one_oldest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -694,7 +700,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_one_newest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -715,7 +721,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     let window_main = gui_data.window_main.clone();
     buttons_popover_select_custom.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -737,7 +743,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     let window_main = gui_data.window_main.clone();
     buttons_popover_unselect_custom.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -758,7 +764,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_all_images_except_biggest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
@@ -778,7 +784,7 @@ pub fn connect_popover_select(gui_data: &GuiData) {
     let notebook_main = gui_data.main_notebook.notebook_main.clone();
     let main_tree_views = gui_data.main_notebook.get_main_tree_views();
     buttons_popover_select_all_images_except_smallest.connect_clicked(move |_| {
-        let nb_number = notebook_main.current_page().unwrap();
+        let nb_number = notebook_main.current_page().expect("Current page not set");
         let tree_view = &main_tree_views[nb_number as usize];
         let nb_object = &NOTEBOOKS_INFO[nb_number as usize];
 
